]> git.imager.perl.org - imager.git/commitdiff
[rt #70656] apply the last the Debian spelling fixes
authorTony Cook <tony@develop-help.com>
Mon, 10 Oct 2011 12:42:38 +0000 (23:42 +1100)
committerTony Cook <tony@develop-help.com>
Mon, 10 Oct 2011 12:42:38 +0000 (23:42 +1100)
Changes
image.c
lib/Imager/APIRef.pod
samples/samp-form.cgi

diff --git a/Changes b/Changes
index c3e1a9d9503100b29e859b06e45ec3c45c05e6d5..ef24e99fd76c77c8a83aa74c32647c2e008a36b2 100644 (file)
--- a/Changes
+++ b/Changes
@@ -14,6 +14,9 @@ Bug fixes:
  - make default text color non-transparent
    https://rt.cpan.org/Ticket/Display.html?id=71469
 
+ - apply the last of the Debian unforwarded spelling fixes
+   https://rt.cpan.org/Ticket/Display.html?id=70656
+
 Imager 0.85_01 - 10 Oct 2011
 ==============
 
diff --git a/image.c b/image.c
index 6cb49d48a4062327f0f5a8f89ab6466f5e2db84c..b84d05a031c5d6b620ccfcdc5ba8188981e2fa9a 100644 (file)
--- a/image.c
+++ b/image.c
@@ -318,7 +318,7 @@ i_img_info(i_img *im, i_img_dim *info) {
 /*
 =item i_img_setmask(C<im>, C<ch_mask>)
 =category Image Information
-=synopsis // only channel 0 writeable 
+=synopsis // only channel 0 writable 
 =synopsis i_img_setmask(img, 0x01);
 
 Set the image channel mask for C<im> to C<ch_mask>.
index f080131c8974980aedda7fed06078e02d7434db0..b03206bb8a7e0c8e2499bda92fd287e9abf4c3b4 100644 (file)
@@ -81,7 +81,7 @@ Imager::APIRef - Imager's C API - reference.
   # Image Implementation
 
   # Image Information
// only channel 0 writeable 
   i_img_setmask(img, 0x01);
   int mask = i_img_getmask(img);
   int channels = i_img_getchannels(img);
@@ -1615,7 +1615,7 @@ From: File image.c
 
 =item i_img_setmask(C<im>, C<ch_mask>)
 
// only channel 0 writeable 
   i_img_setmask(img, 0x01);
 
 Set the image channel mask for C<im> to C<ch_mask>.
index 93368bc8cbfa6b9b6190618c656dcdfa2a570593..0929385613e4572f1b62eed2ed2be6192ed8d1c2 100755 (executable)
@@ -138,7 +138,7 @@ This has the advantage that you aren't handling a second potentially
 expensive CGI request to generate the image, but it means you need
 some mechanism to manage the files (for example, a cron job to delete
 old files), and you need to make some directory under the document
-root writeable by the user that your web server runs CGI programs as,
+root writable by the user that your web server runs CGI programs as,
 which may be a security concern.
 
 Also, if you're generating large numbers of large images, you may end
@@ -81,7 +81,7 @@ Imager::APIRef - Imager's C API - reference.
 
   # Image Information
-  // only channel 0 writeable 
+  // only channel 0 writable 
   i_img_setmask(img, 0x01);
   int mask = i_img_getmask(img);
@@ -1615,7 +1615,7 @@ From: File image.c
 =item i_img_setmask(C<im>, C<ch_mask>)
 
-  // only channel 0 writeable 
+  // only channel 0 writable 
   i_img_setmask(img, 0x01);
 